@@ -17,7 +17,7 @@
 	(C) Heikki Holstila 2010
 */
 
-#include <QtNetwork>
+#include <Qt>
 #include <QDBusConnection>
 #include <QDBusInterface>
 
@@ -29,18 +29,17 @@
 #include "blacklistselect.h"
 #include "aaptinterface.h"
 #include "settings.h"
+#include "mainwindow.h"
 
-PackageSelector::PackageSelector(Package* pkg, AAptInterface* apt, Settings* set, QWidget *parent) :
+PackageSelector::PackageSelector(Package* pkg, AAptInterface* apt, Settings* set, MainWindow* mw, QWidget *parent) :
     QDialog(parent),
-    ui(new Ui::PackageSelector)
+	ui(new Ui::PackageSelector), iNetworkAccessManager(0), iChangelogFetched(false), iFetchInProgress(false)
 {
-    ui->setupUi(this);	
+	ui->setupUi(this);
 	iPkg = pkg;
 	iAptInterface = apt;
 	iSettings = set;
-	iNetworkAccessManager = 0;
-	iChangelogFetched = false;
-	iFetchInProgress = false;
+	iMainWindow = mw;
 	iChangelog = "";
 
 	ui->pushButton_website->setIcon(QPixmap("/usr/share/icons/hicolor/48x48/hildon/general_web.png"));
@@ -526,6 +525,9 @@ void PackageSelector::queryChangelog()
 	if( iChangelogFetched || iFetchInProgress )
 		return;
 
+	if( iMainWindow )
+		iMainWindow->openNetworkConnection();
+
 	iChangelogFetched = false;
 	iFetchInProgress = true;
 	iChangelog = "";
@@ -541,7 +543,7 @@ void PackageSelector::queryChangelog()
 
 	if( !iNetworkAccessManager ) {
 		iNetworkAccessManager = new QNetworkAccessManager(this);
-		connect(iNetworkAccessManager,SIGNAL(finished(QNetworkReply*)),this,SLOT(changelogFetchNetworkReply(QNetworkReply*)));
+		connect(iNetworkAccessManager,SIGNAL(finished(QReply*)),this,SLOT(changelogFetchNetworkReply(QReply*)));
 
 		if( iSettings->qsettings()->value("use_proxies").toBool() && !iSettings->qsettings()->value("http_proxy").toString().isEmpty() )
 		{
@@ -574,7 +576,7 @@ void PackageSelector::changelogFetchNetworkReply(QNetworkReply* reply)
 
 		qDebug() << "changelog fetched";
 	} else {
-		iChangelog = "Not available (Network error)";
+		iChangelog = "Not available ( error)";
 		qDebug() << "changelog fetch error:" << reply->error() << reply->errorString();
 	}
 
